/**
 * Библиотека для быстрой интеграции PayQR на интернет-сайты (PHP 5.x)
 * Версия библиотеки: 1.2
 * Помощь, вопросы и сообщения об ошибках: api@payqr.ru
 *
 * Рекомендуемые сферы применения: интернет-магазины, онлайн-сервисы, браузерные игры
 *
 * API PayQR и библиотека PayQR обладают большим количеством функций и возможностей, часть из которых нужна только небольшому количеству интернет-сайтов. Для ускорения и упрощения интеграции реализуйте у себя только то, что актуально для бизнес-логики конкретно вашего интернет-сайта, остальное игнорируйте и оставляйте "как есть" (оно по умолчанию работоспособно в библиотеке и уже корректно взаимодействует с API PayQR).
 */


___
Структура библиотеки:
|- payqr_config.php // файл конфигурации, подключает все необходимые файлы для работы
|- payqr_receiver.php // основной файл, принимающий уведомления от PayQR (абсолютная ссылка на него указывается в личном кабинете PayQR в поле "URL для уведомлений")
|- payqr_classifier.csv // классификатор товаров/услуг PayQR (при желании указывать категории товарных позиций в кнопках PayQR)
|- classes
  |- payqr_authentication.php // класс проверки валидности уведомлений и ответов от PayQR (проверки секретных ключей)
  |- payqr_autoload.php // класс автозагрузки классов библиотеки PayQR
  |- payqr_base.php // класс проверки конфигурации библиотеки PayQR
  |- payqr_base_request.php // класс реализации запросов в PayQR
  |- payqr_button.php // класс конструктора кнопки PayQR
  |- payqr_curl.php // класс обертки для cURL
  |- payqr_curl_response.php // класс обработки результатов запросов cURL
  |- payqr_no_curl.php // класс замены cURL в отправке запросов в PayQR, если cURL отсутствует
  |- payqr_exeption.php // класс исключения во время работы с API PayQR
  |- payqr_invoice.php // класс работы с объектами "Счет на оплату"
  |- payqr_invoice_action.php // класс методов по объектам "Счет на оплату"
  |- payqr_json_validator.php // класс JSON валидатора
  |- payqr_logs.php // класс ведения отладочных логов
  |- payqr_receiver.php // класс приема уведомлений от PayQR
  |- payqr_revert.php // класс работы с объектами "Возвраты"
  |- payqr_revert_action.php // класс методов по объектам "Возвраты"
  |- payqr_product.php // класс формирования товарных позиций в кнопке PayQR
  |- payqr_deliverycase.php // класс формирования способов доставки в ответе на уведомление invoice.deliverycases.updating
  |- payqr_pickpoint.php // класс формирования пунктов самовывоза в ответе на уведомление invoice.pickpoints.updating
|- example // примеры для ознакомления по принятию уведомлений от PayQR и направлению запросов в PayQR
  |- button.php // файл примера работы с конструктором кнопки PayQR
  |- receiver.php // файл примера обработчика уведомлений от PayQR
  |- sender.php // файл примера работы с запросами в PayQR
  |- simple_receiver.php // файл примера обработчика уведомлений от PayQR (минимальная версия обработчика)
|- handlers // файлы обработчиков для уведомлений от PayQR о событиях в PayQR
|- handlers_errors // файлы обработчиков ошибок
  |- invoice_action_error.php // файл обработки ошибок по запросам в PayQR по объектам "Счет на оплату"
  |- revert_action_error.php // файл обработки ошибок по запросам в PayQR по объектам "Возвраты"
  |- reciver_error.php // файл обработки ошибок во время получения уведомлений от PayQR


/**
 * Базовая инструкция по интеграции "Быстрый старт": https://payqr.ru/api 
 * Справочник API PayQR: https://payqr.ru/api/ecommerce
 * Полная документация по API PayQR: https://payqr.ru/api/doc
 * Ответы на частые вопросы по интеграции с PayQR: https://payqr.ru/api/faq
 * 
 * API PayQR использует архитектуру REST (http://wikipedia.org/wiki/Representational_state_transfer).
 * API PayQR поддерживает CORS (http://wikipedia.org/wiki/Cross-origin_resource_sharing) для безопасного взаимодействия с приложениями на клиентской стороне.
 * Данные в рамках API PayQR направляются в формате JSON (http://wikipedia.org/wiki/JSON).
 * Уведомления о событиях от PayQR поступают в интернет-сайт обычными http-/https-запросами (http://wikipedia.org/wiki/Webhook).
 * Обновления API PayQR всегда осуществляются с сохранением обратной совместимости.
 */